/**
 * Copyright (C) 2016  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.tabs.bottom;

import org.dussan.vaadin.dtabs.DTabs;
import org.dussan.vaadin.dtabs.demo.tabs.StringGenerator;
import org.dussan.vaadin.dtabs.demo.ui.context.TabContext;

import com.vaadin.server.FontAwesome;
import com.vaadin.server.Resource;
import com.vaadin.ui.Label;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.TabSheet.Tab;

public class PaddedTabbar
    extends TabContext
{

    private static final long serialVersionUID = -3642756567021790572L;

    @Override
    protected void init()
    {
        StringGenerator sg = new StringGenerator();
        Resource[] icons = { FontAwesome.AMBULANCE, FontAwesome.HAND_PAPER_O, FontAwesome.LIGHTBULB_O,
            FontAwesome.SEND_O, FontAwesome.TV };

        DTabs tabs = new DTabs();
        tabs.setTabBarBottom( true )
            .setFramedTabs( true )
            .setPaddedTabBar( true );

        for ( int index = 1; index <= 5; index++ )
        {
            String tabcaption = sg.nextString( true ) + " " + sg.nextString( false );
            VerticalLayout content = new VerticalLayout();
            content.setMargin( true );
            content.setSpacing( true );
            content.addComponent( new Label( "Content for tab " + index ) );
            if ( index == 2 )
            {
                content.addComponent( new Label( "Excepteur sint obcaecat cupiditat non proident culpa. Magna pars studiorum, prodita quaerimus." ) );
            }

            Tab tab = tabs.addTab( content, tabcaption );
            tab.setClosable( true );
            tab.setEnabled( true );
            tab.setIcon( icons[index - 1] );

            // First tab is always visible
            if ( index == 1 )
            {
                tab.setEnabled( true );
                tab.setClosable( false );
            }
        }

        setTab( tabs, "StringGenerator sg = new StringGenerator();\n"//
            + "Resource icons[] = { FontAwesome.AMBULANCE, FontAwesome.HAND_PAPER_O, FontAwesome.LIGHTBULB_O, FontAwesome.SEND_O, FontAwesome.TV };\n"//
            + "\n"//
            + "DTabs tabs = new DTabs();\n"//
            + "tabs.setTabBarBottom(true).setFramedTabs(true).setPaddedTabBar(true);\n"//
            + "\n"//
            + "for (int index = 1; index <= 5; index++) {\n"//
            + "\tString tabcaption = sg.nextString(true) + \" \" + sg.nextString(false);\n"//
            + "\tVerticalLayout content = new VerticalLayout();\n"//
            + "\tcontent.setMargin(true);\n"//
            + "\tcontent.setSpacing(true);\n"//
            + "\tcontent.addComponent(new Label(\"Content for tab \" + index));\n"//
            + "\tif (index == 2) {\n"//
            + "\t\tcontent.addComponent(\n"//
            + "\t\t\tnew Label(\"Excepteur sint obcaecat cupiditat non proident culpa. Magna pars studiorum, prodita quaerimus.\"));\n"//
            + "\t}\n"//
            + "\n"//
            + "\tTab tab = tabs.addTab(content, tabcaption);\n"//
            + "\ttab.setClosable(true);\n"//
            + "\ttab.setEnabled(true);\n"//
            + "\ttab.setIcon(icons[index - 1]);\n"//
            + "\n"//
            + "\t// First tab is always visible\n"//
            + "\tif (index == 1) {\n"//
            + "\t\ttab.setEnabled(true);\n"//
            + "\t\ttab.setClosable(false);\n"//
            + "\t}\n"//
            + "}\n"//
        );
    }

}
